@@ -46,7 +46,9 @@ class Shaper(object):
                  disable_or_statements=True,
                  allow_opt_cardinality=True,
                  disable_exact_cardinality=False,
-                 shapes_namespace=SHAPES_DEFAULT_NAMESPACE
+                 shapes_namespace=SHAPES_DEFAULT_NAMESPACE,
+                 limit_remote_instances=-1,
+                 wikidata_annotation=False
                  ):
         """
 
@@ -115,6 +117,8 @@ class Shaper(object):
         self._disable_or_statements = disable_or_statements
         self._allow_opt_cardinality = allow_opt_cardinality
         self._disable_exact_cardinality = disable_exact_cardinality
+        self._limit_remote_instances = limit_remote_instances
+        self._wikidata_annotation = wikidata_annotation
 
         self._depth_for_building_subgraph = depth_for_building_subgraph
         self._track_classes_for_entities_at_last_depth_level = track_classes_for_entities_at_last_depth_level
@@ -127,8 +131,6 @@ class Shaper(object):
 
         self._add_shapes_namespaces_to_namespaces_dict()
 
-        #TODO check correctness of these last seven params
-
 
         #The following two atts are used for optimizations
         self._built_remote_graph = get_remote_graph_if_needed(endpoint_url=url_endpoint,
@@ -145,7 +147,8 @@ class Shaper(object):
                                                         rdflib_graph=self._rdflib_graph,
                                                         raw_graph=self._raw_graph,
                                                         input_format=self._input_format,
-                                                        source_file_graph=self._graph_file_input)
+                                                        source_file_graph=self._graph_file_input,
+                                                        limit_remote_instances=self._limit_remote_instances)
 
 
 
@@ -237,7 +240,8 @@ class Shaper(object):
                                     namespaces_dict=self._namespaces_dict,
                                     output_format=output_format,
                                     instantiation_property=self._instantiation_property,
-                                    disable_comments=self._disable_comments)
+                                    disable_comments=self._disable_comments,
+                                    wikidata_annotation=self._wikidata_annotation)
 
     def _build_class_profiler(self):
         return get_class_profiler(target_classes_dict=self._target_classes_dict,
@@ -262,7 +266,8 @@ class Shaper(object):
                                   file_target_classes=self._file_target_classes,
                                   built_remote_graph=self._built_remote_graph,
                                   built_shape_map=self._built_shape_map,
-                                  remove_empty_shapes=self._remove_empty_shapes)
+                                  remove_empty_shapes=self._remove_empty_shapes,
+                                  limit_remote_instances=self._limit_remote_instances)
 
 
     def _build_instance_tracker(self):
@@ -291,7 +296,8 @@ class Shaper(object):
                                     shape_qualifiers_mode=self._shape_qualifiers_mode,
                                     built_remote_graph=self._built_remote_graph,
                                     built_shape_map=self._built_shape_map,
-                                    shapes_namespace=self._shapes_namespace)
+                                    shapes_namespace=self._shapes_namespace,
+                                    limit_remote_instances=self._limit_remote_instances)
 
 
     @staticmethod
